==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ContourValueResolverDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let ContourValueResolverDescriptionMetadata = /*@__PURE__*/ (() => {
    class ContourValueResolverDescriptionMetadata extends Base {
        static b(a) {
            if (ContourValueResolverDescriptionMetadata.a == null) {
                ContourValueResolverDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ContourValueResolverDescriptionMetadata.c(ContourValueResolverDescriptionMetadata.a);
            }
            if (a.j(ContourValueResolverDescriptionMetadata.a)) {
                return;
            }
            a.y(ContourValueResolverDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ContourValueResolverDescriptionMetadata.b(a);
            a.z("ContourValueResolver", ContourValueResolverDescriptionMetadata.a);
        }
    }
    ContourValueResolverDescriptionMetadata.$t = /*@__PURE__*/ markType(ContourValueResolverDescriptionMetadata, 'ContourValueResolverDescriptionMetadata');
    ContourValueResolverDescriptionMetadata.a = null;
    return ContourValueResolverDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ContourValueResolverDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let ContourValueResolverDescriptionMetadata = /*@__PURE__*/ (() => {
    class ContourValueResolverDescriptionMetadata extends Base {
        static b(a) {
            if (ContourValueResolverDescriptionMetadata.a == null) {
                ContourValueResolverDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ContourValueResolverDescriptionMetadata.c(ContourValueResolverDescriptionMetadata.a);
            }
            if (a.k(ContourValueResolverDescriptionMetadata.a)) {
                return;
            }
            a.aa(ContourValueResolverDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ContourValueResolverDescriptionMetadata.b(a);
            a.ab("ContourValueResolver", ContourValueResolverDescriptionMetadata.a);
        }
    }
    ContourValueResolverDescriptionMetadata.$t = /*@__PURE__*/ markType(ContourValueResolverDescriptionMetadata, 'ContourValueResolverDescriptionMetadata');
    ContourValueResolverDescriptionMetadata.a = null;
    return ContourValueResolverDescriptionMetadata;
})();
